# Python Thycotic
This is a Python wrapper for [Thycotic Secret Server API](https://updates.thycotic.net/secretserver/restapiguide/10.9/TokenAuth/)

My plan is to first write the methods for the GET requests for all the endpoints, or whatever endpoints I have access to. I won't necessarily add all the request parameters for each request but they are easy to add later.
